Imports DataDynamics.Reports.Extensibility.Data
Imports System.IO

Namespace CsvDataProvider
    Public NotInheritable Class CsvCommand
        Implements Extensibility.Data.IDbCommand

        Private _commandText As String
        Private _connection As IDbConnection
        Private _commandTimeout As Integer
        Private _commandType As CommandType

        Public Sub New(ByVal commandText As String)
            Me.New(commandText, Nothing)
        End Sub

        Public Sub New()
            Me.New(String.Empty)
        End Sub

        Public Sub New(ByVal commandText As String, ByVal connection As CsvConnection)
            _commandText = commandText
            _connection = connection
        End Sub


        '''<summary>
        '''Attempts to cancel the current execution of this command.
        '''</summary>
        '''
        Public Sub Cancel() Implements IDbCommand.Cancel
            Throw New NotImplementedException()
        End Sub

        '''<summary>
        '''Creates a new parameter object for use with this command.
        '''</summary>
        '''
        Public Function CreateParameter() As IDataParameter Implements IDbCommand.CreateParameter
            Throw New NotImplementedException()
        End Function

        '''<summary>
        '''Executes this command's statement and returns the results accessible with an <see cref="T:DataDynamics.Reports.Extensibility.Data.IDataReader">IDataReader</see> object.
        '''</summary>
        '''
        Public Function ExecuteReader() As IDataReader Implements IDbCommand.ExecuteReader
            Return ExecuteReader(DataDynamics.Reports.Extensibility.Data.CommandBehavior.SchemaOnly)
        End Function

        '''<summary>
        '''Executes this command's statement and returns the specified type of results accessible with an <see cref="T:DataDynamics.Reports.Extensibility.Data.IDataReader">IDataReader</see> object.
        '''</summary>
        '''
        Public Function ExecuteReader(ByVal behavior As CommandBehavior) As IDataReader _
            Implements IDbCommand.ExecuteReader
            Return New CsvDataReader(New StringReader(_commandText))
        End Function

        '''<summary>
        '''Returns the command text with the parameters expanded into constants.
        '''</summary>
        '''
        Public Function GenerateRewrittenCommandText() As String Implements IDbCommand.GenerateRewrittenCommandText
            Return _commandText
        End Function

        '''<summary>
        '''Sets or returns the text statement to execute against the data source.
        '''</summary>
        '''
        Public Property CommandText() As String Implements IDbCommand.CommandText
            Get
                Return _commandText
            End Get
            Set(ByVal value As String)
                _commandText = value
            End Set
        End Property

        '''<summary>
        '''Sets or returns the length of time in seconds to wait before terminating the attempt to execute the command and generating an error.
        '''</summary>
        '''
        Public Property CommandTimeout() As Integer Implements IDbCommand.CommandTimeout
            Get
                Return _commandTimeout
            End Get
            Set(ByVal value As Integer)
                _commandTimeout = value
            End Set
        End Property

        '''<summary>
        '''Specifies how to interpret the statement in <see cref="P:DataDynamics.Reports.Extensibility.Data.IDbCommand.CommandText">CommandText</see>.
        '''</summary>
        '''
        Public Property CommandType() As CommandType Implements IDbCommand.CommandType
            Get
                Return _commandType
            End Get
            Set(ByVal value As CommandType)
                _commandType = value
            End Set
        End Property

        '''<summary>
        '''Returns the collection of parameters.
        '''</summary>
        '''
        Public ReadOnly Property Parameters() As IDataParameterCollection Implements IDbCommand.Parameters
            Get
                Throw New NotImplementedException()
            End Get
        End Property

        '''<summary>
        '''Sets or returns the transaction in which this command executes.
        '''</summary>
        '''
        Public Property Transaction() As IDbTransaction Implements IDbCommand.Transaction
            Get
                Throw New NotImplementedException()
            End Get
            Set(ByVal value As IDbTransaction)
                Throw New NotImplementedException()
            End Set
        End Property

        '''<summary>
        '''Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
        '''</summary>
        '''<filterpriority>2</filterpriority>
        Public Sub Dispose() Implements IDisposable.Dispose
            If (Not _connection Is Nothing) Then
                _connection.Dispose()
                _connection = Nothing
            End If
            GC.SuppressFinalize(Me)
        End Sub
    End Class
End Namespace